Structure factor and scattering from radial distribution functions
==================================================================
Please see `examples/examples.ipynb` for information on how to use. 


### Copyright

Copyright (c) 2022, Asmus Ougaard Dohn

